 /*
 * Project name:
     I2C_Simple (Simple test of I2C library routines)
 * Copyright:
     (c) MikroElektronika, 2010
 * Description:
     This program demonstrates usage of the I2C library routines. It
     establishes I2C bus communication with 24AA01 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORTB.
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       BIGAVR6 - ac:Serial_EEPROM
                      http://www.mikroe.com/bigavr/
     Oscillator:      External Clock 08.0000 MHz
     
     Ext. Modules:    on-board Serial EEPROM module
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on EEPROM switches SW14.5 and SW14.7.
     - Pull-up I2C communication lines (PD0 and PD1)
       place jumper J4 in upper position.
     - Turn off PORTC LEDs (SW12.3).
     - Turn on  PORTB LEDs (SW12.2).
*/

void main(){
  DDRB = 0xFF;
  PORTB = 0;                // Configure PORTB as output

  TWI_Init(100000);         // initialize I2C communication
  TWI_Start();              // issue I2C start signal
  TWI_Write(0xA2);          // send byte via I2C  (device address + W)
  TWI_Write(2);             // send byte (address of EEPROM location)
  TWI_Write(0xAA);          // send data (data to be written)
  TWI_Stop();               // issue I2C stop signal

  Delay_100ms();

  TWI_Start();              // issue I2C start signal
  TWI_Write(0xA2);          // send byte via I2C  (device address + W)
  TWI_Write(2);             // send byte (data address)
  TWI_Stop();               // issue I2C stop signal

  TWI_Start();              // issue I2C start signal
  TWI_Write(0xA3);          // send byte (device address + R)
  PORTB = TWI_Read(0u);     // Read the data (NO acknowledge)
  TWI_Stop();               // issue I2C stop signal
}