/*
 * Project name:
     RTC2_Write (Writing date/time data to DS1307 through I2C)
 * Copyright:
     (c) MikroElektronika, 2010
 * Revision History:
     20091212:
        - initial release;
* Description:
     This project is simple demonstration how to set date and time on DS1307
     RTC (real-time clock). The code use TWI module at PORTD.
     The example sets the following:
       TIME: 17:00:00
       DATE: 04/05/2010
     Please refer to DS1307 datasheet for more information on format date
     settings.
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       BIGAVR6 - ac:RTC
                      http://www.mikroe.com/bigavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on I2C lines SW14.5 and SW14.7
     - For proper I2C communication, pins on PORTD must be in the pull-up mode,
       and the LEDs on board switched OFF!
*/

void main() {
  Delay_ms(1000);

  TWI_Init(100000);        // initialize full master mode
  TWI_Start();             // issue start signal
  TWI_Write(0xD0);         // address DS1307
  TWI_Write(0);            // start from word at address (REG0)
  TWI_Write(0x80);         // write $80 to REG0. (pause counter + 0 sec)
  TWI_Write(0);            // write 0 to minutes word to (REG1)
  TWI_Write(0x17);         // write 17 to hours word (24-hours mode)(REG2)
  TWI_Write(0x02);         // write 2 - Monday (REG3)
  TWI_Write(0x04);         // write 4 to date word (REG4)
  TWI_Write(0x05);         // write 5 (May) to month word (REG5)
  TWI_Write(0x0A);         // write 10 to year word (REG6)
  TWI_Stop();              // issue stop signal

  TWI_Start();             // issue start signal
  TWI_Write(0xD0);         // address DS1307
  TWI_Write(0);            // start from word at address 0
  TWI_Write(0);            // write 0 to REG0 (enable counting + 0 sec)
  TWI_Stop();              // issue stop signal
}