/*
 * Project name:
     UART2 (Simple usage of UART2 module library functions)
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This code demonstrates how to use UART2 library routines. Upon receiving
     data via RS232, MCU immediately sends it back to the sender.
 * Test configuration:
     MCU:             ATmega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       BIGAVR6 - ac:UART2
                      http://www.mikroe.com/bigavr/
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on RS232B switches SW13.7 and SW13.8 (board specific).
*/

char uart_rd;

void main() {

  UART2_Init(9600);               // Initialize UART module at 9600 bps
  Delay_ms(100);                  // Wait for UART module to stabilize
  UART2_Write_Text("Ready");
  UART2_Write(13);                // Line Feed
  UART2_Write(10);                // Carriage Return
  
  while (1) {                     // Endless loop
    if (UART2_Data_Ready()) {     // If data is received,
      uart_rd = UART2_Read();     // Read the received data,
      UART2_Write(uart_rd);       // And send data via UART
    }
  }
}