/*
 * Project name:
     Button (Demonstration of using Button Library)
 * Copyright:
     (c) Mikroelektronika, 2013.
 * Revision History:
     20130113:
       - initial release (FJ);
 * Description:
     This program demonstrates usage of the on-board button as PORTB input.
     On every PB0 one-to-zero transition PORTC is inverted.
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR v7 - ac:Buttons
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Make sure you turn ON the PORTC LEDs (SW10.7).
     - Put Button Press Level switch PB into upper position and pull-down PORTB.
 */

bit oldstate;                                    // Old state flag

void main() {

  DDB0_bit = 0;                                  // Set pin as input

  DDRC  = 0xFF;                                  // Configure PORTC as output
  PORTC = 0xAA;                                  // Initial PORTC value
  
  oldstate = 0;

  do {
    if (Button(&PINB, 0, 1, 1)) {                // Detect logical one
      oldstate = 1;                              // Update flag
    }
    if (oldstate && Button(&PINB, 0, 1, 0)) {    // Detect one-to-zero transition
      PORTC = ~PORTC;                            // Invert PORTC
      oldstate = 0;                              // Update flag
    }
  } while(1);                                    // Endless loop
}