/*
 * Project name:
     TWI_Advanced (Advanced TWI Example)
 * Copyright:
     (c) Mikroelektronika, 2013.
 * Revision History:
     20130113:
       - initial release (FJ);
 * Description:
     This example features the advanced communication with the 24AA01 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR v7 -  ac:Serial_EEPROM
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    Character Lcd 2x16
                      http://www.mikroe.com/store/components/various/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on TWI switches SW6.3 and SW6.4. (board specific)
     - Turn on on-board Serial EEPROM switches SW5.7 and SW5.8. (board specific)
     - Turn on the LCD backlight on the EasyAVR v7 board at SW3.1. (board specific)
     - Turn off PORTC LEDs at SW10.7. (board specific)
 */

#include "EEPROM_24AA01.h"

// LCD module connections
sbit LCD_RS at PORTA2_bit;
sbit LCD_EN at PORTD6_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDA2_bit;
sbit LCD_EN_Direction at DDD6_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End LCD module connections

char someData[] = "TWI mikroE";
char i ,tmpdata;

void main() {
  #define SINGLE          // comment/uncomment this line to choose single-byte reading mode
  //#define SEQUENTIAL    // comment/uncomment this line to choose sequential reading mode

  EEPROM_24AA01_Init();                     // performs TWI initialization
  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24AA01_WrSingle(i, tmpdata);     // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24AA01_WrSingle(i+1, 0);           // writes string termination
  Delay_ms(20);

  #ifdef SINGLE
    // Example for single-byte read
    i = 1;
    tmpdata = 1;
    while ((tmpdata = EEPROM_24AA01_RdSingle(i)) != 0) {
      Lcd_Chr(2, i, tmpdata);               // displays data from EEPROM on the second row of the Lcd
      Delay_ms(50);
      i++ ;
    }
  #endif
  
  #ifdef SEQUENTIAL
    // Example for sequential data read
    EEPROM_24AA01_RdSeq(1, someData, 13);
    Lcd_Out(2, 1, someData);
  #endif
}