/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) Mikroelektronika, 2013.
 * Revision History:
     20130113:
       - initial release (FJ);
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR v7  - ac:GLCD
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller
                      http://www.mikroe.com/store/components/various/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * Notes:
     - Turn on GLCD backlight switch on development board (SW3.1).
*/  

//Declarations------------------------------------------------------------------
const code char truck_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
char GLCD_DataPort at PORTC;
char GLCD_DataPort_Direction at DDRC;

sbit GLCD_CS1 at PORTB0_bit;
sbit GLCD_CS2 at PORTB1_bit;
sbit GLCD_RS  at PORTA2_bit;
sbit GLCD_RW  at PORTA3_bit;
sbit GLCD_EN  at PORTD6_bit;
sbit GLCD_RST at PORTD7_bit;

sbit GLCD_CS1_Direction at DDB0_bit;
sbit GLCD_CS2_Direction at DDB1_bit;
sbit GLCD_RS_Direction  at DDA2_bit;
sbit GLCD_RW_Direction  at DDA3_bit;
sbit GLCD_EN_Direction  at DDD6_bit;
sbit GLCD_RST_Direction at DDD7_bit;
// End Glcd module connections

void delay2S(){                                  // 2 seconds delay function
  Delay_ms(2000);
}                 

void main() {                       
  char counter;
  char *someText;

  Glcd_Init();                                   // Initialize GLCD
  Glcd_Fill(0x00);                               // Clear GLCD

  while(1) {
    Glcd_Image(truck_bmp);                       // Draw image
    Delay2s(); Delay2s();
    Glcd_fill(0x00);                                  // Clear GLCD
    Glcd_PartialImage(0,0,68,30,128,64,truck_bmp);    // Partial image
    Delay_ms(500);
    Glcd_PartialImage(24,16,68,30,128,64,truck_bmp);
    Delay_ms(500);
    Glcd_PartialImage(56,34,68,30,128,64,truck_bmp);
    Delay2s(); Delay2s();
    Glcd_Fill(0x00);                             // Clear GLCD

    Glcd_Box(62,40,124,56,1);                    // Draw box
    Glcd_Rectangle(5,5,84,35,1);                 // Draw rectangle
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges(2,2,87,38,7,1);
    Delay_ms(1000);
    Glcd_Rectangle_Round_Edges_Fill(8,8,81,32,12,1);
    Delay_ms(1000);
    Glcd_Line(0, 0, 127, 63, 1);                 // Draw line
    Delay2s();

    for(counter = 5; counter < 60; counter+=5 ){ // Draw horizontal and vertical lines
      Delay_ms(250);      
      Glcd_V_Line(2, 54, counter, 1);
      Glcd_H_Line(2, 120, counter, 1);
    }
    Delay2s();

    Glcd_Fill(0x00);                             // Clear Glcd
    Glcd_Set_Font(Character8x7, 8, 7, 32);       // Choose font, see __Lib_GLCDFonts.c in Uses folder
    Glcd_Write_Text("mikroE", 5, 7, 2);          // Write string

    for (counter = 1; counter <= 10; counter++)  // Draw circles
      Glcd_Circle(63,32, 3*counter, 1);
    Delay2s();

    Glcd_Circle_Fill(63,32, 30, 1);              // Draw circles
    Delay2s();

    Glcd_Box(12,20, 70,57, 2);                   // Draw box
    Delay2s();

    Glcd_Fill(0xFF);                             // Fill Glcd
    
    Glcd_Set_Font(Character8x7, 8, 7, 32);       // Change font
    someText = "8x7 Font";
    Glcd_Write_Text(someText, 5, 0, 2);          // Write string
    Delay2s();
  
    Glcd_Set_Font(System3x5, 3, 5, 32);          // Change font
    someText = "3X5 CAPITALS ONLY";
    Glcd_Write_Text(someText, 60, 2, 2);         // Write string
    Delay2s();
    
    Glcd_Set_Font(font5x7, 5, 7, 32);            // Change font
    someText = "5x7 Font";
    Glcd_Write_Text(someText, 5, 4, 2);          // Write string
    Delay2s();
    
    Glcd_Set_Font(FontSystem5x7_v2, 5, 7, 32);   // Change font
    someText = "5x7 Font (v2)";
    Glcd_Write_Text(someText, 50, 6, 2);         // Write string
    Delay2s();
  }
}