/*
 * Project name:
     LM35 Sensor (Temperature measurement)
 * Copyright:
     (c) Mikroelektronika, 2013.
 * Revision History:
     20130113:
       - initial release (FJ);
 * Description:
      A simple example of using the LM35 sensor.
      Temperature is displayed on LCD.
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR v7 - ac:LM35
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    LM35 Sensor, Character Lcd 2x16
                      http://www.mikroe.com/store/components/various/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Place LM35 in proper socket and place jumper J19 in the right position (PA7). (board specific)
     - Turn off PORTA LEDs at SW10.5. (board specific)
     - Turn on the LCD backlight on the EasyAVR v7 board (SW3.1).
 */

// LCD module connections
sbit LCD_RS at PORTA2_bit;
sbit LCD_EN at PORTD6_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDA2_bit;
sbit LCD_EN_Direction at DDD6_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End LCD module connections

//  Set VREF according to the voltage reference :
//  5.00 - power supply jumper set to 5V position (reference = 5V)
//  3.30 - power supply jumper set to 3.3V position (reference = 3.3V)
const unsigned short VREF = 5.00;

unsigned int temp_res = 0;
float temp;
char txt[15];

void main() {
  DDA7_bit = 0;                      // Configure PA7 pin as input
  
  ADC_Init();                        // Initialize ADC
  
  Lcd_Init();                        // Initialize LCD
  Lcd_Cmd(_LCD_CLEAR);               // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off

  Lcd_Out(1, 1, "Temperature :");
  Lcd_Chr(2,8,223);                  // Different LCD displays have different
                                     //   char code for degree
  Lcd_Chr(2,9,'C');                  // Display "C" for Celsius

  temp_res = 0;
  do {
    temp_res = ADC_Get_Sample(7);     // Get 10-bit results of AD conversion
    temp = (temp_res * VREF)/10.240;  // Calculate temperature in Celsius
                                      //  change Vref constant according
                                      //  to the power supply voltage
    FloatToStr(temp, txt);            // Convert temperature to string
    txt[4] = 0;
    Lcd_Out(2,3,txt);                 // Write string in second row
    Delay_ms(300);
  } while(1);
}