/*
 * Project name:
     Seven Segment Display (The 'Hello World' example for the Seven Segment Display)
 * Copyright:
     (c) Mikroelektronika, 2013.
 * Revision History:
     20130113:
       - initial release (FJ);
 * Description:
     This code demonstrates how to display number on one 7-segment display
     (common cathode). Display is connected to PORTC (PC0..PC7, segment A to
     PC0, segment B to PC1, etc); common cathode is connected to the pin PA0 on
     PORTA. Number is incremented every 1s.
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.Board:       EasyAVR v7 - ac:7SEG
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on Seven Segment Display switches SW8.1, SW8.2, SW8.3 and SW8.4. (board specific)
 */

#include "Display_Utils.h"

unsigned short shifter, portd_index;
unsigned int   digit, number;
unsigned short portd_array[4];

void Timer0Overflow_ISR() org IVT_ADDR_TIMER0_OVF {
  PORTA = 0;                             // Turn off all 7seg displays
  PORTC = portd_array[portd_index];      // bring appropriate value to PORTC
  PORTA = shifter;                       // turn on appropriate 7seg. display

  // move shifter to next digit
  shifter <<= 1;
  if (shifter > 8u)
    shifter = 1;

  // increment portd_index
  portd_index++ ;
  if (portd_index > 3u)
    portd_index = 0;            // turn on 1st, turn off 2nd 7seg.
}

void main() {
  DDRA = 0x0f;                  // Configure PORTA as output
  PORTA  = 0;                   // Clear PORTA
  DDRC = 0xff;                  // Configure PORTC as output
  PORTC  = 0;                   // Clear PORTC

  digit = 0;
  portd_index = 0;
  shifter = 1;

  number = 1234;                // Initial number value

  TCCR0 = 0x03;                 // ClkI/O/64 (From prescaler)
  SREG_I_bit = 1;               // Interrupt enable
  TOIE0_bit  = 1;               // Timer0 overflow interrupt enable

  do {
    digit = number / 1000u ;             // extract thousands digit
    portd_array[3] = mask(digit);        // and store it to PORTC array
    digit = (number / 100u) % 10u;       // extract hundreds digit
    portd_array[2] = mask(digit);        // and store it to PORTC array
    digit = (number / 10u) % 10u;        // extract tens digit
    portd_array[1] = mask(digit);        // and store it to PORTC array
    digit = number % 10u;                // extract ones digit
    portd_array[0] = mask(digit);        // and store it to PORTC array

    Delay_ms(1000);                      // one second delay

    number++ ;                           // increment number
    if (number > 9999u)
      number = 0;

  } while(1);                            // endless loop
}