/*
 * Project name:
     TWI_Advanced (Advanced TWI Example)
 * Copyright:
     (c) MikroElektronika, 2005-2010.
 * Revision History:
     20080930:
       - initial release;     
 * Description:
     This example features the advanced communication with the 24C02 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/easyavr/v6/
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    ac:Serial_EEPROM_Board (24C02)
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Connect EEPROM extra board on PORTC and Lcd.
     - Pull-up TWI communication lines (RC0 and RC1) and turn off PORTC LEDs.
     - Turn on LCD backlight switch SW10.7 (board specific).
*/

#include "EEPROM_24C02.h"

// Lcd module connections
sbit LCD_RS at PORTD2_bit;
sbit LCD_EN at PORTD3_bit;
sbit LCD_D4 at PORTD4_bit;
sbit LCD_D5 at PORTD5_bit;
sbit LCD_D6 at PORTD6_bit;
sbit LCD_D7 at PORTD7_bit;

sbit LCD_RS_Direction at DDD2_bit;
sbit LCD_EN_Direction at DDD3_bit;
sbit LCD_D4_Direction at DDD4_bit;
sbit LCD_D5_Direction at DDD5_bit;
sbit LCD_D6_Direction at DDD6_bit;
sbit LCD_D7_Direction at DDD7_bit;
// End Lcd module connections

char someData[] = "TWI mikroE";
char i, tmpdata;

//  Main
void main() {

  #define SINGLE                            // comment/uncomment this line to choose reading mode

  Delay_ms(1000);

  EEPROM_24C02_Init();                      // performs TWI initialization
  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24C02_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24C02_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  #ifdef SINGLE
  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24C02_RdSingle(i)) != 0) {
    Lcd_Chr(2, i+1, tmpdata);               // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }
  #else
  // Example for sequential data read
  EEPROM_24C02_RdSeq(1, someData, 13);
  Lcd_Out(2, 3, someData);
  #endif
}