/*
 * Project name:
     PortExpander (Demonstration of the Port Expander library routines)
 * Copyright:
     (c) Mikroelektronika, 2005-2010.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This project is simple demonstration how to use Port Expander Library functions.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/easyavr/v6/
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    ac:Port_Expander_Board on PORTB
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn ON the PORTC LEDs at SW8.3 (board specific).
 */

// Port Expander module connections
sbit  SPExpanderRST at PORTB0_bit;
sbit  SPExpanderCS  at PORTB1_bit;
sbit  SPExpanderRST_Direction at DDB0_bit;
sbit  SPExpanderCS_Direction  at DDB1_bit;
// End Port Expander module connections

unsigned char i = 0;

void main() {

  DDRC = 0xFF;                           // Set PORTC as output

  // If Port Expander Library uses SPI1 module
  SPI1_Init();                           // Initialize SPI module used with PortExpander

//  // If Port Expander Library uses SPI2 module
//  SPI2_Init();                           // Initialize SPI module used with PortExpander

  Expander_Init(0);                      // Initialize Port Expander

  Expander_Set_DirectionPortA(0, 0x00);  // Set Expander's PORTA to be output

  Expander_Set_DirectionPortB(0,0xFF);   // Set Expander's PORTB to be input
  Expander_Set_PullUpsPortB(0,0xFF);     // Set pull-ups to all of the Expander's PORTB pins

  while(1) {                             // Endless loop
    Expander_Write_PortA(0, i++);        // Write i to expander's PORTA
    PORTC = Expander_Read_PortB(0);      // Read expander's PORTB and write it to LEDs
    Delay_ms(50);
  }
  
}