/*
 * Project name:
     Eeprom (Demonstration of using EEPROM Library) 
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This is a demonstration of using library functions for handling of the
     AVR's internal EEPROM module. First, some data is written to EEPROM
     in byte and block mode; then the data is read from the same locations and 
     displayed on PORTA, PORTB and PORTC.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/easyavr/v6/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on PORTA PORTB and PORTC LEDs.
*/

char ii;                                   // loop variable

void main(){
   DDRA = 0xFF;                            // Set signal port as output
   DDRB = 0xFF;                            // Set signal port as output
   DDRC = 0xFF;                            // Set signal port as output
   
   PORTA = 0x00;                           // Clear signal ports
   PORTB = 0x00;
   PORTC = 0x00;
   Delay_ms(2000);

   EEPROM_Write(0x02,0xAA);                // Write some data at address 2
   EEPROM_Write(0x150,0x55);               // Write some data at address 0x150

   PORTA = EEPROM_Read(0x02);              // Read data from address 2 and display it on PORTA
   PORTB = EEPROM_Read(0x150);             // Read data from address 0x150 and display it on PORTB

   Delay_ms(1000);

   for(ii = 0; ii < 32; ii++)              // EEPROM write loop
     EEPROM_Write(0x100+ii, ii);           // Write data to address 0x100+ii

   for(ii = 0; ii < 32; ii++) {            // EEPROM read loop
     PORTC = EEPROM_Read(0x100+ii);        // Read data from address 0x100+ii
     Delay_ms(100);                        //   and display it on PORTC
   }
   
}