/*
 * Project name:
     ManchesterReceiver (Demonstration on usage of Manchester code library functions)
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This code shows how to use Manchester Library for receiving data. The
     example works in conjuction with Transmitter example which sends the word
     "mikroElektronika" using Manchester encoding. During the receive process,
     message letters are being written on the LCD.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/easyavr/v6/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    LCD 2x16, Superhet receiver on some household-use frequency
                      (e.g. 433MHz) - OPTIONAL
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on LCD backlight switch SW9.8 (board specific).
     - If you decide to try this example(s) with transmitter/receiver modules,
       make sure that both transmitter and a receiver work on the same frequency!
 */

// LCD module connections
sbit LCD_RS at PORTD2_bit;
sbit LCD_EN at PORTD3_bit;
sbit LCD_D4 at PORTD4_bit;
sbit LCD_D5 at PORTD5_bit;
sbit LCD_D6 at PORTD6_bit;
sbit LCD_D7 at PORTD7_bit;

sbit LCD_RS_Direction at DDD2_bit;
sbit LCD_EN_Direction at DDD3_bit;
sbit LCD_D4_Direction at DDD4_bit;
sbit LCD_D5_Direction at DDD5_bit;
sbit LCD_D6_Direction at DDD6_bit;
sbit LCD_D7_Direction at DDD7_bit;
// End LCD module connections

// Manchester module connections
sbit MANRXPIN at PINB0_bit;
sbit MANRXPIN_Direction at DDB0_bit;
sbit MANTXPIN at PORTB1_bit;
sbit MANTXPIN_Direction at DDB1_bit;
// End Manchester module connections

char error, ErrorCount, temp;

void main() {
  ErrorCount = 0;

  Lcd_Init();                                     // Initialize LCD
  Lcd_Cmd(_LCD_CLEAR);                            // Clear LCD display

  Man_Receive_Init();                             // Initialize Receiver
  
  while (1) {                                     // Endless loop

      Lcd_Cmd(_LCD_FIRST_ROW);                    // Move cursor to the 1st row
       
      while (1) {                                 // Wait for the "start" byte
        temp = Man_Receive(&error);               // Attempt byte receive 
        if (temp == 0x0B)                         // "Start" byte, see Transmitter example
          break;                                  // We got the starting sequence
        if (error)                                // Exit so we do not loop forever
          break;
      }
        
      do {
        temp = Man_Receive(&error);               // Attempt byte receive
        if (error) {                              // If error occured
          Lcd_Chr_CP('?');                        // Write question mark on LCD
          ErrorCount++;                           // Update error counter
          if (ErrorCount > 20) {                  // In case of multiple errors
            temp = Man_Synchro();                 // Try to synchronize again
            //Man_Receive_Init();                 // Alternative, try to Initialize Receiver again
            ErrorCount = 0;                       // Reset error counter
            }
          }
        else {                                    // No error occured
          if (temp != 0x0E)                       // If "End" byte was received(see Transmitter example)
            Lcd_Chr_CP(temp);                     //   do not write received byte on LCD
            }
        Delay_ms(25);
      }
      while (temp != 0x0E) ;                      // If "End" byte was received exit do loop
   }
}