/*
 * Project name:
     PS2 (Demonstration on using mikroC's PS/2 keyboard library)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     In this example, key(s) pressed on the PS/2 keyboard are read and transferred
     to PC through serial port connection. Various basic keyboard activities are
     tested: "normal" keys, keys with <Shift> pressed, keys with <Caps Lock>
     pressed, numerical keypad ON/OFF and keys. The result is visible on PC, via
     USART Terminal tool.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.board:       EasyAVR6 - ac:PS_2
                      http://www.mikroe.com/easyavr/v6/
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    PS/2 standard 101-keys keyboard
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Some keyboards with various multimedia attachments on them (especially the
       cheap ones) tend to "choke" the communication by constantly sending
       requests on various multimedia object's status (volume, mouse pos. etc.).
       This may slow down the communication pace with the MCU.
     - LEDs off and pull-ups on PORTC may be required.
     - RX and TX UART switches on EasyAVR6 should be turned ON(SW9.2 and SW9.5).
 */


unsigned short keydata = 0, special = 0, down = 0;
 
sbit PS2_Data         at PINC0_bit;
sbit PS2_Clock_Input  at PINC1_bit;
sbit PS2_Clock_Output at PORTC1_bit;

sbit PS2_Data_Direction   at DDC0_bit;
sbit PS2_Clock_Direction  at DDC1_bit;

void main() {

  UART1_Init(19200);        // Initialize UART module at 19200 bps
  Ps2_Config();             // Init PS/2 Keyboard
  Delay_ms(100);            // Wait for keyboard to finish
  UART1_Write_Text("Ready");

  do {
    if (Ps2_Key_Read(&keydata, &special, &down)) {
      if (down && (keydata == 16)) {        // Backspace
         UART1_Write(0x08);
      }
      else if (down && (keydata == 13)) {   // Enter
        UART1_Write('\r');                  // Send carriage return to usart terminal
        //Usart_Write('\n');                // Uncomment this line if usart terminal also expects line feed
                                            // for new line transition
      }
      else if (down && !special && keydata) {
        UART1_Write(keydata);
      }
    }
    Delay_ms(10);                           // Debounce
  } while (1);
}